Documentation
¶
Index ¶
- type Client
- func (c *Client) ChangeDir(dirPath string) error
- func (c *Client) Close() error
- func (c *Client) CurrentDir() (string, error)
- func (c *Client) Download(srcPath, destPath string) error
- func (c *Client) DownloadToBytes(filePath string) ([]byte, error)
- func (c *Client) GetMd5(data []byte) string
- func (c *Client) MakeDir(dirPath string) error
- func (c *Client) Retr(filePath string) ([]byte, error)
- func (c *Client) Store(fileName string, fileContent io.Reader) error
- func (c *Client) Upload(srcPath, destPath string) error
- func (c *Client) UploadAndCheckMd5(srcPath, destPath string) bool
- type Config
- type Ftp
- type Server
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Conn *ftp.ServerConn
Log *zdpgo_log.Log
}
func (*Client) DownloadToBytes ¶
DownloadToBytes 下载文件并转换我bytes数组
func (*Client) UploadAndCheckMd5 ¶
UploadAndCheckMd5 上传文件并校验MD5值
type Config ¶
type Config struct {
Debug bool `yaml:"debug" json:"debug"`
LogFilePath string `yaml:"log_file_path" json:"log_file_path"`
WorkDir string `yaml:"root_dir" json:"root_dir"`
Host string `yaml:"host" json:"host"`
Port int `yaml:"port" json:"port"`
Username string `yaml:"username" json:"username"`
Password string `yaml:"password" json:"password"`
}
type Ftp ¶
func NewWithConfig ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package errwrap implements methods to formalize error wrapping in Go.
|
Package errwrap implements methods to formalize error wrapping in Go. |
|
examples
|
|
|
client
command
|
|
|
server
command
|
|
|
Package ftp implements a FTP client as described in RFC 959.
|
Package ftp implements a FTP client as described in RFC 959. |
|
pkg/credentials
Package credentials provides credential retrieval and management for S3 compatible object storage.
|
Package credentials provides credential retrieval and management for S3 compatible object storage. |
Click to show internal directories.
Click to hide internal directories.